
 ****************** Reads, cleans, and merges the main data set ******************

  program cleanmain
 	local silent `1'
	****  CODEBOOK FOR SILENT:
	*   1 -> Nice stata output display
	*   0 -> Display everything 
	*************************************
 	local collapsed `2'
	****  CODEBOOK FOR COLLAPSED:
	*   4 -> Generate Collapsed and Collapsed Networks file
	*   3 -> Generate Collapsed Network file
	*   2 -> Generate Collapsed file
	*   1 -> Only generate Bilateral file
	*************************************

  ******  Local variables to run the stuff quietly or noisily	
  
	if `silent'==1 {
		local sil "qui"
		local noi " "
	}
	else {
		local sil " "
		local noi "qui"
	}

  ******* Program starts
  
	di " "
	di "   Reads, cleans, and merges the main data set", as text
	di "---------------------------------------------------------------------------"
	
	di "      Read original data", as text _continue
	
	clear
	local path="$data"
	`sil' import excel codeij codei countryi codej countryj period year ///
				 qualityflag stockij group totaltoshare using ///
				 "`path'Bilateral_migration_corrected.xls", ///
				 clear cellrange(A2) sheet("Data")
	
	di "..." as text
	
	di "      Create averages by group", as text _continue
	
	`sil' keep if year==1960 | year==1970 | year==1980 | year==1990 | year==2000
	`sil' drop if countryi==countryj
	`sil' drop if countryi=="Korea, Rep." & countryj=="Korea, Republic of"
	`sil' gen temp1=1
	`sil' bysort codei group year: egen countgr=sum(temp1)
	`sil' replace stockij=totaltoshare if countgr==1 & totaltoshare!=. & group!="NIU"
	`sil' replace totaltoshare=0 if countgr==1 & totaltoshare!=.
	`sil' replace group="NIU"  if countgr==1 & totaltoshare==0
	`sil' gen avgroup=totaltoshare/countgr
	`sil' replace avgroup=stockij if stockij!=.
	`sil' drop temp1
	
	di "..." as text
	
	**** Requires the file Ozdenetal11.dta obtained from program cleanozden ****
	di "      Merge with Ozden et al (2011)", as text _continue
	
	local path="$data"
	`sil' merge 1:1 codei codej year using "`path'Ozdenetal11.dta"
	`sil' drop _merge 
	`sil' drop if countryi==countryj
	di "...", as text
	
	di "      Merge with covariates", as text _continue
	preserve
		local path="$data"
		`sil' import excel codej countryj period year lnyor5 lnyor10 popor5 ///
			popor10 shengenor5 shengenor10 waror5 instabilityor5 polityor5 ///
			sqpolityor5 waror10 instabilityor10 polityor10 sqpolityor10 govor5 ///
			govor10 pppor5 pppor10 young10 young5 using "`path'Origin.xlsx", ///
			clear cellrange(A2) sheet("Data")
			
		`sil' keep if year==1960 | year==1970 | year==1980 | year==1990 | year==2000
		drop lnyor5 popor5 shengenor5 waror5 instabilityor5 polityor5 sqpolityor5 ///
			 govor5 young5
		local vlst "lnyor popor shengenor waror instabilityor polityor govor"
		local vlst "`vlst' sqpolityor young"
		foreach v of local vlst {
			`sil' rename `v'10 `v'
		}
		local path="$data"
		`sil' save "`path'Origin.dta", replace

		local path="$data"
		`sil' import excel codei countryi period year lnydest5 lnydest10 popdest5 ///
			popdest10 shengendest5 shengendest10 udest5 udest10 agedepdest5 ///
			agedepdest10 govdest5 govdest10 pppdest5 pppdest10 using ///
			"`path'Destination.xlsx", clear cellrange(A2) sheet("Data")
			
		`sil' keep if year==1960 | year==1970 | year==1980 | year==1990 | year==2000
		drop lnydest5 popdest5 shengendest5 udest5 agedepdest5 govdest5 pppdest5
		local vlst "lnydest popdest shengendest udest agedepdest govdest pppdest"
		foreach v of local vlst {
			`sil' rename `v'10 `v'
		}
		local path="$data"
		`sil' save "`path'Destination.dta", replace
		
		local path="$data"
		`sil' import excel codei countryi codej countryj border comlang colony ///
		ldist using "`path'Origin_destination.xlsx", clear cellrange(A2) sheet("Data")
					
		local path="$data"
		`sil' save "`path'Origin_destination.dta", replace		
		
	restore
	
	local path="$data"
	`sil' merge m:1 codej year using "`path'Origin.dta"
	`sil' drop _merge 
	
	local path="$data"
	`sil' merge m:1 codei year using "`path'Destination.dta"
	`sil' drop _merge 

	di "...", as text

	local path="$data"
	`sil' merge m:1 codei codej using "`path'Origin_destination.dta"
	`sil' drop _merge 
	
	
	`sil' replace popor=popor/1000
	`sil' replace popdest=popdest/1000
	`sil' replace young=young*4/1000 
		/*multiplied by 4 because it is average of the four 5-year groups */
	cap gen lnpopor=.
	cap gen lnpopdest=.
	cap gen yor=.
	cap gen ydest=.
	cap gen lnyoung=.
	drop lnpopor lnpopdest yor ydest lnyoung
	`sil' gen lnpopor=ln(popor)
	`sil' gen lnpopdest=ln(popdest)
	`sil' gen ydest=exp(lnydest)
	`sil' gen yor=exp(lnyor)
	`sil' gen lnyoung=ln(young)
	`sil' replace ydest=ydest/1000
	`sil' replace yor=yor/1000
	`sil' replace udest=udest*100


	`sil' xtset codeij period
		
	*Generate relevant variables*
		
	di "      Generate some variables", as text _continue

	`sil' gen lnstock=ln(avgroup)
	`sil' tab period, gen(dt_)
	`sil' tab codei, gen(di_)
	`sil' tab codej, gen (dj_)
	`sil' gen ygap=ydest-yor
	`sil' gen pol2=polity^2
	`sil' gen wt=1
	`sil' gen lnygap=lnydest-lnyor

	di "...", as text
		
	*Generate dummies*

	di "      Generate dummies", as text _continue
	forvalues t=1/5 {
		forvalues j=1/188  {
			`sil' gen djt_`j'_`t'=dj_`j' *dt_`t'
		}
	}
			
		
	forvalues t=1/5 {
		forvalues i=1/24  {
			`sil' gen dit_`i'_`t'=di_`i' *dt_`t'
		}
	}	
		
	forvalues i=1/24 {
		forvalues j=1/188  {
			`sil' gen dij_`i'_`j'=di_`i' *dj_`j'
		}
	}
		
	di "...", as text
			
			
	*Create interaction variables for heterogeneous effects*
		
	di "      Generate interactions", as text _continue

	local y "ydest yor lnydest lnyor"
	local interact "ldist comlang colony border"
	local all "`y' `interact'"
		
	foreach var of local all {
		cap gen average_`var'=.
		drop average_`var'
		`sil' egen average_`var'=mean(`var')
	}

	local interactlist " "
	foreach var of local y {
		foreach intv of local interact {
			cap gen `var'_`intv'=.
			drop `var'_`intv'
			`sil' gen `var'_`intv'=(`var'-average_`var')*(`intv'-average_`intv')
			local interactlist "`interactlist' `var'_`intv'"
		}
	}
	di "...", as text
			
			
	* Generate networks variable *

	di "      Generate networks variable", as text _continue
	
	`sil' xtset codeij period
		
	`sil' gen networks=ll.lnstock
	
	cap gen groupnum=.
	cap gen laggroupnum=.
	cap gen temp=.
	drop groupnum temp laggroupnum
	`sil' egen temp = group(group)
	`sil' replace temp = 0 if group=="NIU"
	`sil' egen groupnum = group(temp)
	`sil' gen laggroupnum=ll.groupnum

	preserve
		gen count=1
		collapse (sum) count, by(codei period groupnum laggroupnum)
		drop count
		`sil' gen biggroup=laggroupnum
		`sil' replace biggroup=groupnum*100 if laggroupnum==1 & groupnum!=1
		`sil' gen currgroup=groupnum if laggroupnum!=.
		`sil' replace currgroup=laggroupnum*100 if groupnum==1 & laggroupnum!=1 ///
															& laggroupnum!=.
		sort codei period biggroup currgroup
		`sil' bys codei period biggroup: gen numbig=_n
		`sil' replace numbig=. if biggroup==.
		`sil' bys codei period biggroup: egen maxbig=max(num)
		sort codei period currgroup biggroup
		`sil' bys codei period currgroup: gen numgr=_n
		`sil' replace numgr=. if currgroup==.
		`sil' bys codei period currgroup: egen maxgr=max(numgr)
		`sil' gen unsolved=1
		`sil' replace unsolved=. if biggroup==.
		`sil' replace unsolved=0 if maxbig==1 & maxgr==1
		
		`sil' replace currgroup=biggroup*100 if maxgr==1 & maxbig>1
		`sil' replace biggroup=currgroup*100 if maxbig==1 & maxgr>1

		drop numgr maxgr numbig maxbig
		`sil' bys codei period biggroup: egen temp1=min(currgroup)
		`sil' bys codei period biggroup: egen temp2=max(currgroup)
		`sil' gen maxbig=temp2-temp1+1 if biggroup!=.

		drop temp1 temp2
		`sil' bys codei period currgroup: egen temp1=min(biggroup)
		`sil' bys codei period currgroup: egen temp2=max(biggroup)
		`sil' gen maxgr=temp2-temp1+1 if currgroup!=.

		`sil' replace unsolved=0 if maxbig==1 & maxgr==1
		
		local stopping=1
		
		while `stopping'>0 {
		
			drop temp1 temp2
			`sil' gen temp1=biggroup if maxgr!=1
			`sil' bys codei period currgroup: egen temp2=min(temp1)
			`sil' replace biggroup=temp2 if temp2!=. & maxbig==1

			drop temp1 temp2 maxbig
			`sil' bys codei period biggroup: egen temp1=min(currgroup)
			`sil' bys codei period biggroup: egen temp2=max(currgroup)
			`sil' gen maxbig=temp2-temp1+1 if biggroup!=.

			drop temp1 temp2 maxgr
			`sil' bys codei period currgroup: egen temp1=min(biggroup)
			`sil' bys codei period currgroup: egen temp2=max(biggroup)
			`sil' gen maxgr=temp2-temp1+1 if currgroup!=.

			drop temp1 temp2
			`sil' gen temp1=currgroup if maxbig!=1
			`sil' bys codei period biggroup: egen temp2=min(temp1)
			`sil' replace currgroup=temp2 if temp2!=. & maxgr==1

			drop temp1 temp2 maxbig
			`sil' bys codei period biggroup: egen temp1=min(currgroup)
			`sil' bys codei period biggroup: egen temp2=max(currgroup)
			`sil' gen maxbig=temp2-temp1+1 if biggroup!=.

			drop temp1 temp2 maxgr
			`sil' bys codei period currgroup: egen temp1=min(biggroup)
			`sil' bys codei period currgroup: egen temp2=max(biggroup)
			`sil' gen maxgr=temp2-temp1+1 if currgroup!=.

			`sil' count if unsolved==1 & maxbig==1 & maxgr==1
			local stopping=r(N)
			`sil' replace unsolved=0 if maxbig==1 & maxgr==1

		}
		
		`sil' replace biggroup=10000 if unsolved==1
		
		keep codei period laggroup groupnum biggroup
			
		local path="$data"
		`sil' save "`path'Network_crossroad.dta", replace
		
	restore

	cap gen biggroup=.
	drop biggroup
	local path="$data"
	`sil' merge m:1 codei period laggroup groupnum ///
									using "`path'Network_crossroad.dta"
	
	di "...", as text
	
	*Save Bilateral*

	di "      Save Bilateraldata file", as text _continue	
	local path="$data"
	`sil' save "`path'Bilateraldata.dta", replace
	di "...", as text
	di " ", as text

	if `collapsed'==2 | `collapsed'==4{

		*Collapse general*
		
		preserve
			di "      Collapse general", as text _continue

			local varlist0 "lnstock ydest yor ldist comlang colony border lnpopor "
			local varlist0 "`varlist0' lnpopdest lnyor lnydest"
			
			`sil' gen groupid=group
			`sil' replace groupid=countryj if group=="NIU"
			
			`sil' collapse (mean) `varlist0' `interactlist' ygap lnygap dt_* ///
			di_* dj_* djt_* dit_* dij_* udest agedepdest govdest waror polity ///
			pol2 lnyoung (sum) wt (sd) st_lnstock=lnstock st_ydest=ydest ///
			st_yor=yor st_lnydest=lnydest st_lnyor=lnyor st_ldist=ldist ///
			st_comlang=comlang st_colony=colony st_border=border ///
			st_lnpopor=lnpopor st_lnpopdest=lnpopdest, by(codei groupid period) fast
			
			`sil' replace st_lnstock=0 if wt==1
			`sil' replace st_ydest=0 if wt==1
			`sil' replace st_yor=0 if wt==1
			`sil' replace st_lnydest=0 if wt==1
			`sil' replace st_lnyor=0 if wt==1
			`sil' replace st_ldist=0 if wt==1
			`sil' replace st_comlang=0 if wt==1
			`sil' replace st_colony=0 if wt==1
			`sil' replace st_border=0 if wt==1
			`sil' replace st_lnpopor=0 if wt==1
			`sil' replace st_lnpopdest=0 if wt==1

			`sil' drop if period==.
			
			di "...", as text

			di "      Save Collapsed file", as text _continue	
			local path="$data"
			`sil' save "`path'Collapsed.dta", replace
			di "...", as text
		restore
	}

	if `collapsed'==3 | `collapsed'==4 {

		*Collapse networks

		di "      Collapse networks", as text _continue

		local varlist0 "lnstock ydest yor ldist comlang colony border lnpopor "
		local varlist0 "`varlist0' lnpopdest lnyor lnydest"
			
		`sil' replace biggroup=codej+10000 if biggroup==1
			
		`sil' collapse (mean) `varlist0' `interactlist' networks dt_* di_* ///
		dj_* djt_* dit_* dij_* (sum) wt, by(codei biggroup period) fast
		
		`sil' drop if period==.
			
		di "...", as text

		di "      Save Collapsed Networks file", as text _continue	
		local path="$data"
		`sil' save "`path'Collapsed_networks.dta", replace
		di "...", as text

	}
	
  end
