
 ***************** Generates the tables of descriptive statistics *****************
 
  program descriptives
 	local silent `1'
	****  CODEBOOK FOR SILENT:
	*   1 -> Nice stata output display
	*   0 -> Display everything 
	*************************************
 
  ******  Local variables to run the stuff quietly or noisily	
  
	if `silent'==1 {
		local sil "qui"
		local noi " "
	}
	else {
		local sil " "
		local noi "qui"
	}

  ******* Program starts
  
	di " "
	di "   Generates the tables of descriptive statistics", as text
	di "---------------------------------------------------------------------------"

	di "      Read data", as text _continue
	local path="$data"
	`sil' use "`path'Bilateraldata.dta", clear
	di "...", as text

	di "      Descriptive statistics for migrant stocks", as text _continue
	
	cap gen wt=1
	cap gen groupid=.
	drop wt groupid
	`sil' gen wt=1
	`sil' egen groupid=group(group codei year)
	`sil' replace groupid=codej*10000 if stockij!=.

	preserve
		`sil' collapse (mean) avgroup (sum) wt, by(codei group period groupid)

		matrix coefstatsstocks=J(25,10,.)
		forvalues c=1/24 {
			`sil' sum avgroup [weight=wt] if codei==`c'
			matrix coefstatsstocks[`c',1]=r(N)
			matrix coefstatsstocks[`c',2]=r(mean)
			matrix coefstatsstocks[`c',3]=r(sd)
			matrix coefstatsstocks[`c',4]=r(min)
			matrix coefstatsstocks[`c',5]=r(max)
		}

		`sil' sum avgroup
		matrix coefstatsstocks[25,1]=r(N)
		matrix coefstatsstocks[25,4]=r(min)
		matrix coefstatsstocks[25,5]=r(max)

	restore

	forvalues c=1/24 {
		`sil' sum stockij if codei==`c'
		matrix coefstatsstocks[`c',6]=r(N)
		matrix coefstatsstocks[`c',7]=r(mean)
		matrix coefstatsstocks[`c',8]=r(sd)
		matrix coefstatsstocks[`c',9]=r(min)
		matrix coefstatsstocks[`c',10]=r(max)
	}

	`sil' sum stockij
	matrix coefstatsstocks[25,6]=r(N)
	matrix coefstatsstocks[25,7]=r(mean)
	matrix coefstatsstocks[25,8]=r(sd)
	matrix coefstatsstocks[25,9]=r(min)
	matrix coefstatsstocks[25,10]=r(max)
		
	`sil' sum avgroup
	matrix coefstatsstocks[25,2]=r(mean)
	matrix coefstatsstocks[25,3]=r(sd)

	
	di "...", as text

	di "      Do tables:", as text 
	
	local head1 "di _newline   \begin{table}[!t]\centering _newline     \caption"
	local head1 "`head1'{Descriptive Statistics for Migrant Stocks} _newline     "
	local head1 "`head1' \label{tab:descrstats} _newline _newline "
			
	local head2 "  \resizebox{0.999\textwidth}{!}{ _newline    \begin{tabular}{@"
	local head2 "`head2'{\hskip 0.5cm}L{2.6cm}R{1cm}R{1.2cm}R{1.2cm}R{0.8cm}R{1.5cm"
	local head2 "`head2'}cR{1cm}R{1.2cm}R{1.2cm}R{0.9cm}R{1.5cm}@{\hskip 0.2cm}}"
	local head2 "`head2' _newline"
			
	local head3 "       \\ [-0.25cm] _newline        \hline\hline \\ [-0.15cm] "
	local head3 "`head3'_newline                            &  \multicolumn{5}{c}{"
	local head3 "`head3'Full sample}                                               "
	local head3 "`head3'              &  &"
	
	local head4 "  \multicolumn{5}{c}{Ungrouped observations only}                "
	local head4 "`head4'                             \\ [0.05cm] _newline      \c"
	local head4 "`head4'line{2-6}\cline{8-12} \\ [-0.25cm] _newline              "
	local head4 "`head4'               &      Obs.        &      Mean        &    "
	
	local head5 "  Sd.         &      Min         &      Max         &  &         "
	local head5 "`head5'Obs.     &       Mean       &       Sd.        &       Min "
	local head5 "`head5'       &         Max      \\ [0.05cm] _newline      \hlin"
	local head5 "`head5'e \\ [-0.25cm]"

	local labrows1 "Australia"
	local labrows1 "`labrows1' Austria"
	local labrows1 "`labrows1' Belgium"
	local labrows1 "`labrows1' Canada"
	local labrows1 "`labrows1' Denmark"
	local labrows1 "`labrows1' Finland"
	local labrows1 "`labrows1' France"
	local labrows1 "`labrows1' Germany"
	local labrows1 "`labrows1' Greece"
	
	local labrows2 "Iceland"
	local labrows2 "`labrows2' Ireland"
	local labrows2 "`labrows2' Italy"
	local labrows2 "`labrows2' Japan"
	local labrows2 "`labrows2' Korea(Rep.)"
	local labrows2 "`labrows2' Luxembourg"
	local labrows2 "`labrows2' Netherlands"
	local labrows2 "`labrows2' NewZealand"
	local labrows2 "`labrows2' Norway"
	
	local labrows3 "Portugal"
	local labrows3 "`labrows3' Spain"
	local labrows3 "`labrows3' Sweden"
	local labrows3 "`labrows3' Switzerland"
	local labrows3 "`labrows3' UnitedKingdom"
	local labrows3 "`labrows3' UnitedStates"
	local labrows3 "`labrows3' All"
	
	local rowsep "di      \hline \\ [-0.25cm]"

	local ending1 "di      \hline\hline\\ [-0.2cm] _newline    \end{tabular}}"
	local ending1 "`ending1' _newline _newline    \begin{tablenotes} _newline "
	local ending1 "`ending1'        The unit of observation is origin-destination"
	local ending1 "`ending1'-year. All figures (except "
	
	local ending2 "the number of observations) are in individual counts. Left pa"
	local ending2 "`ending2'nel refers to the baseline sample, which includes dis"
	local ending2 "`ending2'aggregate bilateral _newline        observations an"
	local ending2 "`ending2'd grouped observations"
	
	local ending3 "---grouped observations are weighted by the number of countri"
	local ending3 "`ending3'es included in the group. Right panel restricts the s"
	local ending3 "`ending3'ample to disaggregated bilateral observations."
	local ending3 "`ending3' _newline     \end{tablenotes} _newline "

	local ending4 "    \vspace{-0.7cm} _newline \end{table}"

	dotables "TableDescriptive.tex" /// 
			 "p" "0" ///
			 "n" /// 
			 "5" "`head1'" "`head2'" "`head3'" "`head4'" "`head5'" /// 
			 "1" ///
			    "25 10 1 5 1 24" ///
					"3" "`labrows1'" "`labrows2'" "`labrows3'" /// 
					"0" /// 
					"statsstocks" /// 
					"1" "1 1" "`rowsep'" /// 
					"0" /// 
			 "4" "`ending1'" "`ending2'" "`ending3'" "`ending4'"

			 
	**************************************************************************

	di "      Descriptive statsistics for  migrant stocks Ozden et al (2011)", ///
																as text _continue
	
	cap gen wt=1
	cap gen groupid=.
	drop wt groupid
	`sil' gen wt=1
	`sil' egen groupid=group(group codei year)
	`sil' replace groupid=codej*10000 if stockij!=.

	preserve
		`sil' collapse (mean) stockozdenetal (sum) wt, ///
													by(codei group period groupid)

		matrix coefstatsstocksozd=J(25,10,.)
		forvalues c=1/24 {
			`sil' sum stockozdenetal [weight=wt] if codei==`c'
			matrix coefstatsstocksozd[`c',1]=r(N)
			matrix coefstatsstocksozd[`c',2]=r(mean)
			matrix coefstatsstocksozd[`c',3]=r(sd)
			matrix coefstatsstocksozd[`c',4]=r(min)
			matrix coefstatsstocksozd[`c',5]=r(max)
		}

		`sil' sum stockozdenetal
		matrix coefstatsstocksozd[25,1]=r(N)
		matrix coefstatsstocksozd[25,4]=r(min)
		matrix coefstatsstocksozd[25,5]=r(max)

	restore

	forvalues c=1/24 {
		`sil' sum stockozdenetal if codei==`c' & groupid>=10000
		matrix coefstatsstocksozd[`c',6]=r(N)
		matrix coefstatsstocksozd[`c',7]=r(mean)
		matrix coefstatsstocksozd[`c',8]=r(sd)
		matrix coefstatsstocksozd[`c',9]=r(min)
		matrix coefstatsstocksozd[`c',10]=r(max)
	}

	`sil' sum stockozdenetal if groupid>=10000
	matrix coefstatsstocksozd[25,6]=r(N)
	matrix coefstatsstocksozd[25,7]=r(mean)
	matrix coefstatsstocksozd[25,8]=r(sd)
	matrix coefstatsstocksozd[25,9]=r(min)
	matrix coefstatsstocksozd[25,10]=r(max)
		
	`sil' sum stockozdenetal
	matrix coefstatsstocksozd[25,2]=r(mean)
	matrix coefstatsstocksozd[25,3]=r(sd)

	
	di "...", as text

	di "      Do tables:", as text 
	
	local head1 "di _newline   \begin{table}[!t]\centering _newline     \caption"
	local head1 "`head1'{Descriptive Statistics for Migrant Stocks in \citet*{Ozden"
	local head1 "`head1'etal11}} _newline      \label{tab:descrstats-ozdenetal} "
	local head1 "`head1'_newline _newline "
			
	local head2 "  \resizebox{0.999\textwidth}{!}{ _newline    \begin{tabular}{@"
	local head2 "`head2'{\hskip 0.5cm}L{2.6cm}R{1cm}R{1.2cm}R{1.2cm}R{0.8cm}R{1.5cm"
	local head2 "`head2'}cR{1cm}R{1.2cm}R{1.2cm}R{0.9cm}R{1.5cm}@{\hskip 0.2cm}}"
	local head2 "`head2' _newline"
			
	local head3 "       \\ [-0.25cm] _newline        \hline\hline \\ [-0.15cm] "
	local head3 "`head3'_newline                            &  \multicolumn{5}{c}{"
	local head3 "`head3'Full sample}                                               "
	local head3 "`head3'              &  &"
	
	local head4 "  \multicolumn{5}{c}{Ungrouped observations only}                "
	local head4 "`head4'                             \\ [0.05cm] _newline      \c"
	local head4 "`head4'line{2-6}\cline{8-12} \\ [-0.25cm] _newline              "
	local head4 "`head4'               &      Obs.        &      Mean        &    "
	
	local head5 "  Sd.         &      Min         &      Max         &  &         "
	local head5 "`head5'Obs.     &       Mean       &       Sd.        &       Min "
	local head5 "`head5'       &         Max      \\ [0.05cm] _newline      \hlin"
	local head5 "`head5'e \\ [-0.25cm]"

	local labrows1 "Australia"
	local labrows1 "`labrows1' Austria"
	local labrows1 "`labrows1' Belgium"
	local labrows1 "`labrows1' Canada"
	local labrows1 "`labrows1' Denmark"
	local labrows1 "`labrows1' Finland"
	local labrows1 "`labrows1' France"
	local labrows1 "`labrows1' Germany"
	local labrows1 "`labrows1' Greece"
	
	local labrows2 "Iceland"
	local labrows2 "`labrows2' Ireland"
	local labrows2 "`labrows2' Italy"
	local labrows2 "`labrows2' Japan"
	local labrows2 "`labrows2' Korea(Rep.)"
	local labrows2 "`labrows2' Luxembourg"
	local labrows2 "`labrows2' Netherlands"
	local labrows2 "`labrows2' NewZealand"
	local labrows2 "`labrows2' Norway"
	
	local labrows3 "Portugal"
	local labrows3 "`labrows3' Spain"
	local labrows3 "`labrows3' Sweden"
	local labrows3 "`labrows3' Switzerland"
	local labrows3 "`labrows3' UnitedKingdom"
	local labrows3 "`labrows3' UnitedStates"
	local labrows3 "`labrows3' All"
	
	local rowsep "di      \hline \\ [-0.25cm]"

	local ending1 "di      \hline\hline\\ [-0.2cm] _newline    \end{tabular}}"
	local ending1 "`ending1' _newline _newline    \begin{tablenotes} _newline "
	local ending1 "`ending1'        The unit of observation is origin-destination"
	local ending1 "`ending1'-year. All figures (except "
	
	local ending2 "the number of observations) are in individual counts. Left pa"
	local ending2 "`ending2'nel refers to the baseline sample, which includes dis"
	local ending2 "`ending2'aggregate bilateral _newline        observations an"
	local ending2 "`ending2'd grouped observations"
	
	local ending3 "---grouped observations are weighted by the number of countri"
	local ending3 "`ending3'es included in the group. Right panel restricts the s"
	local ending3 "`ending3'ample to disaggregated bilateral observations."
	local ending3 "`ending3' _newline     \end{tablenotes} _newline "

	local ending4 "    \vspace{-0.7cm} _newline \end{table}"

	dotables "TableDescriptive_Ozdenetal.tex" /// 
			 "p" "0" ///
			 "n" /// 
			 "5" "`head1'" "`head2'" "`head3'" "`head4'" "`head5'" /// 
			 "1" ///
			    "25 10 1 5 1 24" ///
					"3" "`labrows1'" "`labrows2'" "`labrows3'" /// 
					"0" /// 
					"statsstocksozd" /// 
					"1" "1 1" "`rowsep'" /// 
					"0" /// 
			 "4" "`ending1'" "`ending2'" "`ending3'" "`ending4'"



	**************************************************************************

	di "      Descriptive statistics of the Explanatory Variables", ///
																as text _continue


	local listexvar "ydest yor ldist comlang colony border popor popdest"
	local listexvar "`listexvar' udest agedepdest govdest waror polityor young"

	matrix coefstatsvars=J(14,10,.)


	preserve
		`sil' collapse (mean) ydest yor ldist comlang colony border popor ///
				popdest udest agedepdest govdest waror polityor young stockij ///
				(sum) wt, by(codei group period groupid)


		local y=1
		foreach x of local listexvar  {
			`sil' sum `x' [weight=wt] if ldist!=.
				matrix coefstatsvars[`y',1]=r(N)
				matrix coefstatsvars[`y',2]=r(mean)
				matrix coefstatsvars[`y',3]=r(sd)
				matrix coefstatsvars[`y',4]=r(min)
				matrix coefstatsvars[`y',5]=r(max)

			`sil' sum `x' [weight=wt] if stockij!=.
				matrix coefstatsvars[`y',6]=r(N)
				matrix coefstatsvars[`y',7]=r(mean)
				matrix coefstatsvars[`y',8]=r(sd)
				matrix coefstatsvars[`y',9]=r(min)
				matrix coefstatsvars[`y',10]=r(max)
				local ++y
		}
		
	restore
	
					
	di "...", as text

	di "      Do tables:", as text 
	
	local head1 "di _newline   \begin{table}[!t]\centering _newline     \caption"
	local head1 "`head1'{Descriptive Statistics of the Explanatory Variables} _new"
	local head1 "`head1'line      \label{tab:descrstatsvariables} _newline _newli"
	local head1 "`head1'ne "
			
	local head2 "  \resizebox{0.999\textwidth}{!}{ _newline    \begin{tabular}{@"
	local head2 "`head2'{\hskip 0.5cm}L{4.9cm}R{0.9cm}R{0.9cm}R{0.9cm}R{1cm}R{1.3cm"
	local head2 "`head2'}cR{0.9cm}R{0.9cm}R{1cm}R{1cm}R{1.3cm}@{\hskip 0.2cm}}"
	local head2 "`head2' _newline"
			
	local head3 "       \\ [-0.25cm] _newline        \hline\hline \\ [-0.15cm] "
	local head3 "`head3'_newline                            &  \multicolumn{5}{c}{"
	local head3 "`head3'Full sample}                                               "
	local head3 "`head3'              &  &"
	
	local head4 "  \multicolumn{5}{c}{Ungrouped observations only}                "
	local head4 "`head4'                             \\ [0.05cm] _newline      "
	local head4 "`head4'\cline{2-6}\cline{8-12} \\ [-0.25cm] _newline          "
	local head4 "`head4'                              &      Obs.        &      Mea"
	local head4 "`head4'n    "
	
	local head5 "    &      Sd.         &      Min         &      Max         &  &"
	local head5 "`head5'         Obs.     &       Mean       &       Sd.        &  "
	local head5 "`head5'     Min        &    Max   \\ [0.05cm] _newline  "
	local head5 "`head5'    \hline \\ [-0.25cm]"

	local labrows1 "GDPpcdest.(1,000s)"
	local labrows1 "`labrows1' GDPpcorigin(1,000s)"
	local labrows1 "`labrows1' LogDistance"
	local labrows1 "`labrows1' Commonlanguage"
	local labrows1 "`labrows1' Colonialrelationship"
	local labrows1 "`labrows1' Commonborder"
	local labrows1 "`labrows1' Pop.origin(millions)"
	
	local labrows2 "Pop.dest.(millions)"
	local labrows2 "`labrows2' Unemploymentratedest.(\%)"
	local labrows2 "`labrows2' Agedep.dest.(\%old/w-age)"
	local labrows2 "`labrows2' Governmentsharedest."
	local labrows2 "`labrows2' Warorigin"
	local labrows2 "`labrows2' PolityIVorigin"
	local labrows2 "`labrows2' Youngpop.origin(age15-34)"
	
	local rowsep "di      \hline \\ [-0.25cm]"

	local ending1 "di      \hline\hline\\ [-0.2cm] _newline    \end{tabular}}"
	local ending1 "`ending1' _newline _newline    \begin{tablenotes} _newline "
	local ending1 "`ending1'        The unit of observation is origin-destination"
	local ending1 "`ending1'-year. Left panel includes "
	
	local ending2 "both observations with bilateral migrant data, and observatio"
	local ending2 "`ending2'ns for which migrant stocks are grouped  _newline  "
	local ending2 "`ending2'       --- which are grouped equivalently, weighting "
	local ending2 "`ending2'by the number of countries in the group. Right panel"
	
	local ending3 " includes only observations with available bilateral stocks."
	local ending3 "`ending3' _newline      \end{tablenotes} _newline      \vsp"
	local ending3 "`ending3'ace{-0.7cm} _newline     \end{table}"

	dotables "TableDescriptive2.tex" /// 
			 "c" "0 2 2 2 2 0 2 2 2 2" ///
			 "n" /// 
			 "5" "`head1'" "`head2'" "`head3'" "`head4'" "`head5'" /// 
			 "1" ///
			    "14 10 1 5 1 8" ///
					"2" "`labrows1'" "`labrows2'" /// 
					"0" /// 
					"statsvars" /// 
					"1" "1 1" "`rowsep'" /// 
					"0" /// 
			 "3" "`ending1'" "`ending2'" "`ending3'"




	**************************************************************************

	di "      Distribution of discrepancies with Ozden et al (2011)", ///
																as text _continue
	
	`sil' gen discrep=stockij-stockozdenetal

	`sil' histogram discrep if discrep>100000 | discrep<-100000, ///
			discrete width(100000) frequency fc(navy) lc(none) ///
	   lw(none) xmti(-1800000(600000)600000) xsc(range(-1800000 600000)) ///
								xlabel(-1800000(600000)600000, format(%9.0fc)) ///
	   ysc(range(0 25)) ylab(0 5 10 15 20 25, format(%6.0f)) ///
	   ysize(8.8) xsize(8.8) ///
	   legend(off) ///
	   plotregion(margin(zero) fcolor(white) lcolor(white) ilcolor(white)) ///
	   graphregion(fcolor(white) lcolor(white) ilcolor(white)) ///
	   yline(0, lcolor(black)) ///
	   yline(0 5 10 15 20 25, lc(gray)) ///
	   title("") note("") ytitle("") xtitle("") 
			 

	local path="$grfold"
	`sil' graph export "`path'Distrib_discrepancies_Ozdenetal1.ps", replace ///
			logo(off) mag(98) tmargin(0) lmargin(0) or(portrait) ///
			fontface("Times New Roman")

	`sil' histogram discrep if discrep<=100000 & discrep>=-100000 ///
			& (discrep>10000 | discrep<-10000), ///
			discrete width(10000) frequency fc(navy) lc(none) ///
	   lw(none) xmti(-100000(50000)100000) xsc(range(-10000 100000)) ///
								xlabel(-100000(50000)100000, format(%9.0fc)) ///
	   ysc(range(0 120)) ylab(0 20 40 60 80 100 120, format(%6.0f)) ///
	   ysize(8.8) xsize(8.8) ///
	   legend(off) ///
	   plotregion(margin(zero) fcolor(white) lcolor(white) ilcolor(white)) ///
	   graphregion(fcolor(white) lcolor(white) ilcolor(white)) ///
	   yline(0, lcolor(black)) ///
	   yline(0 20 40 60 80 100 120, lc(gray)) ///
	   title("") note("") ytitle("") xtitle("") 
			 

	local path="$grfold"
	`sil' graph export "`path'Distrib_discrepancies_Ozdenetal2.ps", replace ///
			logo(off) mag(98) tmargin(0) lmargin(0) or(portrait) ///
			fontface("Times New Roman")

	`sil' histogram discrep if discrep<=10000 & discrep>=-10000, ///
			discrete width(1000) frequency fc(navy) lc(none) ///
	   lw(none) xmti(-10000(5000)10000) xsc(range(-1000 10000)) ///
								xlabel(-10000(5000)10000, format(%9.0fc)) ///
	   ysc(range(0 4500)) ylab(0 900 1800 2700 3600 4500, format(%6.0fc)) ///
	   ysize(8.8) xsize(8.8) ///
	   legend(off) ///
	   plotregion(margin(zero) fcolor(white) lcolor(white) ilcolor(white)) ///
	   graphregion(fcolor(white) lcolor(white) ilcolor(white)) ///
	   yline(0, lcolor(black)) ///
	   yline(0 900 1800 2700 3600 4500, lc(gray)) ///
	   title("") note("") ytitle("") xtitle("") 
			 

	local path="$grfold"
	`sil' graph export "`path'Distrib_discrepancies_Ozdenetal3.ps", replace ///
			logo(off) mag(98) tmargin(0) lmargin(0) or(portrait) ///
			fontface("Times New Roman")
	
  end
