

 *****************************  Generic custom tables  ****************************

  program define dotables

   **** Read passed variables

	local t=1
	local filename ``t''			/* File name */
	local ++t
	local dectype ``t''				/* Decimal positions: p=panel; c=column; r=row */
	local ++t
	local decfill ``t''				/* Filling rule (a=automatic, numbers==pattern)*/
	local ++t
	local sestyle ``t''				/* Std. error style: (n=none;s=side;b=below) */
	local ++t
	local headpieces ``t''			/* Number of pieces in which heading is split */
	local ++t
	forvalues i=1/`headpieces' {
		local head`i' ``t''		/* Read heading pieces */
		local ++t
	}
	local panels ``t''				/* Number of panels */
	local ++t
	forvalues i=1/`panels' {
		local dim`i' ``t''		/* Dimensions of the panel: rows, columns, column */
								/* double separators and its position, row */
								/* separators and positions, whether ses are */
								/* provided */
		local ++t				
		local nlab`i' ``t''			/* Number of pieces with labrows */
		local ++t
		forvalues j=1/`nlab`i'' {
			local labrows`i'`j' ``t''	/* Labels for rows */
			local ++t
		}
		local statspos`i' ``t''		/* Rows that include stats (therefore no s.e.)*/
		local ++t
		local matterm`i' ``t''		/* Termin. names matrices containing the data */
		local ++t
		local rowseppieces`i' ``t''	/* Num. pieces in which row separ. are split */
		local ++t
		forvalues j=1/`rowseppieces`i'' {
			if `j'==1 {			
				local idrs`i' ``t''	/* Which pieces include each separator? How */
									/* many, id of each*/
				local ++t
			}
			local rsep`i'`j' ``t''	/* Read row separation pieces */
			local ++t
		}		
		local panelseppieces`i' ``t''	/* Num. of pieces panel sep. are split */
		local ++t
		forvalues j=1/`panelseppieces`i'' {
			local psep`i'`j' ``t''	/* Read panel separation pieces */
			local ++t
		}		
	}
	local endpieces ``t''			/* Number of pieces in which ending is split */
	local ++t

	forvalues i=1/`endpieces' {
		local end`i' ``t''		/* Read ending pieces */
		local ++t
	}

   **** Substitute  by "

	forvalues i=1/`headpieces' {
		local head`i' =  subinstr("`head`i''","",`"""',.)
	}
	forvalues i=1/`panels' {
		forvalues j=1/`panelseppieces`i'' {
			local psep`i'`j' =  subinstr("`psep`i'`j''","",`"""',.)
		}
		forvalues j=1/`rowseppieces`i'' {
			local rsep`i'`j' =  subinstr("`rsep`i'`j''","",`"""',.)
		}
	}
	forvalues i=1/`endpieces' {
		local end`i' =  subinstr("`end`i''","",`"""',.)
	}

   **** Obtain dimensions from strings
  
	forvalues i=1/`panels' {
		gettoken nrows`i' dim`i': dim`i'
		gettoken ncols`i' dim`i': dim`i'
		gettoken ndsp`i' dim`i': dim`i'
		forvalues j=1/`ndsp`i'' {
			gettoken idsp`i'`j' dim`i': dim`i'
		}
		gettoken nrsp`i' dim`i': dim`i'
		forvalues j=1/`nrsp`i'' {
			gettoken irsp`i'`j' dim`i': dim`i'
		}
		gettoken ses`i' dim`i': dim`i'
	}
	
	
	**** Define row separators
	
	forvalues i=1/`panels' {
		forvalues k=1/`nrsp`i'' {
			gettoken howmany idrs`i': idrs`i'
			forvalues j=1/`howmany' {
				gettoken whichone idrs`i': idrs`i'
				local rsep`i'`k'`j' "`rsep`i'`whichone''" 
			}
		}
	}
	
   **** Generate the table
	
	local path="$tabfold"
	cap log close
	qui log using "`path'`filename'", text replace
	`head1'`head2'`head3'`head4'`head5'`head6'`head7'`head8'`head9'`head10'

	forvalues p=1/`panels' {	
		if "`dectype'"=="p" & "`decfill'"=="a" {
			decimals "coef`matterm`p''"
			local dec=$dec
		}
		else if "`dectype'"=="p" {
			gettoken dec decfill: decfill
		}
		gettoken stpos statspos`p': statspos`p'
		
		local k=1
		forvalues r=1/`nrows`p'' {
			if "`dectype'"=="r" & "`decfill'"=="a" {
				matrix temp=coef`matterm`p''[`r',1..`ncols`p'']
				decimals "temp"
				local dec=$dec
			}
			else if "`dectype'"=="r" {
				gettoken dec decfill: decfill
			}

			local s=1
			while "`labrows`p'`s''"=="" {
				local ++s
			}
			gettoken labrow labrows`p'`s': labrows`p'`s'
			local slg=max(13,length("`labrow'"))
			di "       " %`slg's subinstr("`labrow'",""," ",.) "&", _continue
			local j=1
			forvalues c=1/`ncols`p'' {
				if "`dectype'"=="i" & "`decfill'"=="a" {
					local dec=3
					if coef`matterm`p''[`r',`c']>=10 {
						local dec=1
					}
					if coef`matterm`p''[`r',`c']>=100 {
						local dec=0
					}
				}
				else if "`dectype'"=="c" {
					if `c'==1 {
						local decfill2 "`decfill'"
					}
					gettoken dec decfill2: decfill2
				}

				local value=coef`matterm`p''[`r',`c']
				di  %11s  cond(`value'~=.,string(`value',"%9.`dec'fc")," ") ///
															%5s " ", _continue
				if "`sestyle'"=="s" {
					local ses=ses`matterm`p''[`r',`c']
					local g=1
					local temp=`ses'
					if "`temp'"!="." {
						while `temp'>10 {
							local temp=`temp'/10
							local ++g
						}
					}
					local ps=1
					local temp=`g'
					while `temp'>1000 {
						local temp=`temp'/1000
						local ++ps
					}
					local lg=`g'+`ps'+`dec'					
					di "&" %11s cond(`value'~=.,"(" + ///
						string(`ses',"%`lg'.`dec'fc")+")"," ") %5s " ", _continue
				}
				if `c'==`ncols`p'' {
					di "\\"
				}
				else if `ndsp`p''!=0 & `j'<= `ndsp`p'' {
					if `c'==`idsp`p'`j'' {
						di "&  &", _continue
						local ++j
					}
					else {
						di "&", _continue
					}
				}
				else {
					di "&", _continue
				}
			}
			if "`sestyle'"=="b" & `stpos'!=`r' {
				local seslg=`slg'+8
				di %`seslg's "&", _continue
				local j=1
				forvalues c=1/`ncols`p'' {
					if "`dectype'"=="i" & "`decfill'"=="a" {
						local dec=3
						if coef`matterm`p''[`r',`c']>=10 {
							local dec=1
						}
						if coef`matterm`p''[`r',`c']>=100 {
							local dec=0
						}
					}
					else if "`dectype'"=="c" {
						if `c'==1 {
							local decfill2 "`decfill'"
						}
						gettoken dec decfill2: decfill2
					}

					local ses=ses`matterm`p''[`r',`c']
					local g=1
					local temp=`ses'
					if `temp'!=. {
						while `temp'>10 {
							local temp=`temp'/10
							local ++g
						}
					}
					local ps=1
					local temp=`g'
					while `temp'>1000 {
						local temp=`temp'/1000
						local ++ps
					}
					local lg=`g'+`ps'+`dec'
					di  %11s cond(`ses'~=.,"("+string(`ses',"%`lg'.`dec'fc")+ ///
													")"," ") %5s " ", _continue
					if `c'==`ncols`p'' {
						di "\\ [0.08cm]"
					}
					else if `ndsp`p''!=0 & `j'<= `ndsp`p'' {
						if `c'==`idsp`p'`j'' {
							di "&  &", _continue
							local ++j
						}
						else {
							di "&", _continue
						}
					}
					else {
						di "&", _continue
					}
				}
			}
			else if `stpos'==`r' {
				gettoken stpos statspos`p': statspos`p'
			}
			if `nrsp`p''!=0 & `k'<= `nrsp`p'' {
				if `r'==`irsp`p'`k'' {
					`rsep`p'`k'1'`rsep`p'`k'2'`rsep`p'`k'3'`rsep`p'`k'4'`rsep`p'`k'5'`rsep`p'`k'6'`rsep`p'`k'7'`rsep`p'`k'8'
					local ++k
				}
			}
		}	
		`psep`p'1'`psep`p'2'`psep`p'3'`psep`p'4'`psep`p'5'`psep`p'6'`psep`p'7'
	}
	`end1'`end2'`end3'`end4'`end5'`end6'`end7'`end8'`end9'`end10'
	
	di _newline _newline
	
	qui log close

  end
  
  program define decimals
	local matr `1'
	
	clear
	qui svmat `matr'
	qui gen id=_n
	cap reshape long `matr', i(id) j(col)
	qui sum
	global dec=3
	if r(max)>=10 {
		global dec=1
	}
	if r(max)>=100 {
		global dec=0
	}
  end 
 
  
  program define getlabel
	local labrowp1 `1'
	local labrowp2 `2'
	local labrowp3 `3'
	local labrowp4 `4'
	local labrowp5 `5'
	local labrowp6 `6'
	local labrowp7 `7'
	local labrowp8 `8'
	local labrowp9 `9'
	local labrowp10 `10'
	
	clear
	qui svmat `matr'
	qui gen id=_n
	cap reshape long `matr', i(id) j(col)
	qui sum
	global dec=3
	if r(max)>=10 {
		global dec=1
	}
	if r(max)>=100 {
		global dec=0
	}

  end 
 
