
 ***************** Creates figures with bilateral migrant stocks ******************

  program countrypairs
 	local silent `1'
	****  CODEBOOK FOR SILENT:
	*   1 -> Nice stata output display
	*   0 -> Display everything 
	*************************************
 
  ******  Local variables to run the stuff quietly or noisily	
  
	if `silent'==1 {
		local sil "qui"
		local noi " "
	}
	else {
		local sil " "
		local noi "qui"
	}

  ******* Program starts
  
	di " "
	di "   Counts the number of origin countries with grouped data across dest.", ///
																			  as text
	di "---------------------------------------------------------------------------"

	di "      Read file", as text _continue
	local path="$data"
	`sil' use "`path'Bilateraldata.dta", clear
	di "...", as text

	preserve
		di "      Prepare data", as text _continue
		`sil' gen countrypair=upper(substr(countryi,1,3))
		`sil' replace countrypair="AUT" if countryi=="Austria"
		`sil' replace countrypair="NED" if countryi=="Netherlands"
		`sil' replace countrypair="NZL" if countryi=="New Zealand"
		`sil' replace countrypair="ESP" if countryi=="Spain"
		`sil' replace countrypair="UK" if countryi=="United Kingdom"
		`sil' replace countrypair="USA" if countryi=="United States"

		`sil' gen countrypair2=upper(substr(countryj,1,3))
		`sil' replace countrypair2="AUT" if countryj=="Austria"
		`sil' replace countrypair2="CHN" if countryj=="China"
		`sil' replace countrypair2="DRC" if countryj=="Congo, Dem. Rep."
		`sil' replace countrypair2="Indonesia" if countryj=="Indonesia" 
		`sil' replace countrypair2="Korea, D.R." if countryj=="Korea, Dem. Rep." 
		`sil' replace countrypair2="ESP" if countryj=="Spain"
		`sil' replace countrypair2="Turkmenistan" if countryj=="Turkmenistan" 
		`sil' replace countrypair2="UK" if countryj=="United Kingdom"
		`sil' replace countrypair2="UK-IRE" if countryj=="United Kingdom" & ///
											   countryi=="New Zealand"
		`sil' replace countrypair2="UK-IRE" if countryj=="Ireland" & ///
											   countryi=="New Zealand"
		`sil' replace countrypair2="USA" if countryj=="United States"

		`sil' replace countrypair=countrypair2+"_to_"+countrypair

		`sil' drop countrypair2

		`sil' keep if countrypair=="GER_to_DEN" | countrypair=="SWE_to_FIN" | ///
					  countrypair=="DEN_to_ICE" | countrypair=="ESP_to_POR" | ///
					  countrypair=="TUR_to_GRE" | countrypair=="CHN_to_AUS" | ///
					  countrypair=="CHN_to_KOR" | countrypair=="USA_to_IRE" | ///
					  countrypair=="USA_to_JAP" | countrypair=="IND_to_UK" | ///
					  countrypair=="POL_to_AUT" | countrypair=="POL_to_NOR" | ///
					  countrypair=="DRC_to_BEL" | countrypair=="SOM_to_ITA" | ///
					  countrypair=="BRA_to_POR" | countrypair=="SWE_to_NOR" | ///
					  countrypair=="AUS_to_NZL" | countrypair=="UK-IRE_to_NZL"| ///
					  countrypair=="TUR_to_AUT" | countrypair=="TUR_to_SWI" | ///
					  countrypair=="MOR_to_ESP" | countrypair=="UK_to_AUS" | ///
					  countrypair=="KOR_to_JAP" | countrypair=="ECU_to_ESP" | ///
					  countrypair=="ESP_to_FRA" | countrypair=="ALG_to_FRA" | ///
					  countrypair=="ALB_to_GRE" | countrypair=="IRE_to_UK" | ///
					  countrypair=="PHI_to_USA" | countrypair=="MEX_to_USA"
		
		`sil' replace stockij=totaltoshare/2 if countrypair=="UK-IRE_to_NZL" & ///
																		stockij==.
		
		`sil' collapse (sum) stockij popor, by(countrypair year)

		`sil' gen stock=stockij/1000
		`sil' gen emrate=stockij/popor
		`sil' replace stock=. if stock==0
		`sil' replace emrate=. if emrate==0
		di "...", as text
		
		di "      Generate and save graphs", as text _continue
	
		`sil' levels countrypair, local(countrypair)

		foreach c of local countrypair {
			local tit=subinstr("`c'","_"," ",.)
			local cond1 `""`c'"=="UK-IRE_to_NZL"|"`c'"=="AUS_to_NZL"|"`c'"=="DEN_to_SWE""'
			local cond1 `"`cond1'|"`c'"=="YUG_to_SWE"|"`c'"=="SWE_to_NOR"|"`c'"=="'
			local cond1 `"`cond1'"ESP_to_SWI"|"`c'"=="TUR_to_SWI"|"`c'"=="TUR_to_AUT""'
			
			local cond2 `""`c'"=="ESP_to_GER"|"`c'"=="MOR_to_NED"|"`c'"=="BEL_to_NED""'
			local cond2 `"`cond2'|"`c'"=="NED_to_BEL""'
			
			local cond3 `""`c'"=="AUT_to_GER"|"`c'"=="KOR_to_JAP"|"`c'"=="UK_to_AUS"|"'
			local cond3 `"`cond3'"`c'"=="UK_to_IRE"|"`c'"=="ECU_to_ESP"|"`c'"=="'
			local cond3 `"`cond3'"MOR_to_ESP"|"`c'"=="ESP_to_FRA""'
			
			local cond4 `""`c'"=="IRE_to_UK"|"`c'"=="MEX_to_USA"|"`c'"=="PHI_to_USA""'
			
			local cond5 `""`c'"=="ALB_to_GRE"|"`c'"=="ALG_to_FRA""'

			if `cond1' {
				local yshare "0 1.25 2.5 3.75 5"
				local ylevel "0 250 500 750 1000"
				local maxsh "5"
				local maxlev "1000"
				local fmtsh "%5.2f"
			}
			else if `cond2' {
				local yshare "0 3 6 9 12"
				local ylevel "0 250 500 750 1000"
				local maxsh "12"
				local maxlev "1000"
				local fmtsh "%5.1f"
			}
			else if `cond3' {
				local yshare "0 5 10 15 20"
				local ylevel "0 250 500 750 1000"
				local maxsh "20"
				local maxlev "1000"
				local fmtsh "%5.0f"
			}
			else if `cond4' {
				local yshare "0 60 120 180 240"
				local ylevel "0 250 500 750 1000"
				local maxsh "240"
				local maxlev "1000"
				local fmtsh "%5.0f"
			}
			else if `cond5' {
				local yshare "0 30 60 90 120"
				local ylevel "0 250 500 750 1000"
				local maxsh "120"
				local maxlev "1000"
				local fmtsh "%5.0f"
			}
			else {
				local yshare "0 0.25 0.5 0.75 1"
				local ylevel "0 250 500 750 1000"
				local maxsh "1"
				local maxlev "1000"
				local fmtsh "%5.2f"
			}
			
			`sil' twoway (line stock year if countrypair =="`c'" & stock!=., /// 
					lcolor(navy) lwidth(vthick) lpattern(solid) /// 
					xlabel(1960 1970 1980 1990 2000) yaxis(1) ///
					ytitle("") xtitle("") yscale(range(0 `maxlev')) ///
					ylabel(`ylevel', axis(1) format(%5.0f))) ///
				(line emrate year if countrypair=="`c'" & emrate!=., ///
					lcolor(gray) lwidth(vthick) lpattern(dash) /// 
					xlabel(1960 1970 1980 1990 2000) yaxis(2) ///
					ytitle("", axis(2)) xtitle("") yscale(range(0 `maxsh')) ///
					ylabel(`yshare', axis(2) format(`fmtsh'))), ///
			ysize(8.8) xsize(8.8) ///
			legend(off) title("`tit'") note(" ") scale(1.6) ///
			yli(0, lc(black)) yli(`yshare', axis(2) lc(gray)) ///
			plotregion(fcolor(white) lcolor(white) ilcolor(white)) ///
			graphregion(fcolor(white) lcolor(white) ilcolor(white))

			local path="$grfold"
			`sil' graph export "`path'Countrypairs_`c'.ps", replace logo(off) ///
				mag(98) tmargin(0) lmargin(0) or(portrait) font("Times New Roman")
		}
	
	restore
	di "...", as text
 
  end
  
	
