 ***********************************************************************************  
 *     T H I S  P R O G R A M    C O M P U T E S   F I N A L    R E S U L T S      *
 ***********************************************************************************
 
 ///////////////////////////////////////////////////////////////////////////////////
 /// 																			 ///
 ///  This main program and all its subordinated files include all the code that ///
 ///  is needed to replicate the results in "Understanding International         ///
 ///  Migration: Evidence from a New Dataset of Bilateral Stocks (1960-2000)"    ///
 ///  by Joan Llull.                                                             ///
 ///                                                                             ///
 ///  HOW TO USE: The following are the main instructions to use this program.   ///
 ///                                                                             ///
 ///  1) Set the relevant paths in your computer. You need to provide:           ///
 ///        data     -> folder where data sets are stored                        ///
 ///        dofiles  -> folder that includes all do files                        ///
 ///        grfold   -> folder where figures are stored                          ///
 ///        tabfold  -> folder where tables are stored                           ///
 ///        logfold  -> folder where log-files are stored                        ///
 ///                                                                             ///
 ///  2) After reading the global variables with the paths, and the programs in  ///
 ///     each of the subordinate files, you need to run each of the programs     ///
 ///	 for the pieces you would like to replicate.                             ///
 ///                                                                             ///
 /// 3) The programs are:                                                        ///
 ///	  cleanozden   -> reads and cleans the dataset in Ozden et al. (2011)    ///
 ///	  cleanmain    -> Reads, cleans, and merges the main data set            ///
 ///	  countgroup   -> Counts origin countries w/ grouped data across destin. ///
 ///	  histograms   -> Does histograms with available bilateral observations  ///
 ///	  descriptives -> Generates the tables of descriptive statistics         ///
 ///	  immigrate    -> Creates figures with immigrant rates for each destin.  ///
 ///	  countrypairs -> Creates figures with bilateral migrant stocks          ///
 ///	  regs         -> Does the regressions included in the the paper         ///
 ///	  tables (called by regs) -> Does the regression tables                  ///
 ///                                                                             ///
 /// 4) There are also auxiliary programs:                                       ///
 ///	  dotables   -> Generic code that creats tables                          ///
 ///                                                                             ///
 /// 5) The last input for each program equals 1 if one want nice stata output   ///
 ///	to be displayed (recommended), or anything else (e.g. 0) to display all  ///
 ///	 default stata output generated through the process.                     ///
 ///                                                                             ///
 ///  This version: December 2015.  Joan Llull, 2015.                           ///
 ///                                                                             ///
 ///////////////////////////////////////////////////////////////////////////////////

*	clear
	capture set more off
	capture set matsize 11000
	capture set maxvar 32767
	capture set linesize 255
	capture set more off
	pause on
	

  ***** Paths
  
	global unit "PATH HERE"
	global project "RELATIVE PATH HERE"
	global directory "RELATIVE PATH HERE"

	local path="$unit$project"
	  global data "`path'RELATIVE PATH HERE"
	local path="$unit$project$directory"
	  global dofiles "`path'RELATIVE PATH HERE"
	  global grfold "`path'RELATIVE PATH HERE"
	  global tabfold "`path'RELATIVE PATH HERE"
	  global logfold "`path'RELATIVE PATH HERE"

	cd "$unit$project$directory"

  
 ****************************     M A I N   P R O G R A M    ***********************
	
  **** Read programs
 
	capture program drop _all
	local path="$dofiles"
	quietly {
		do "`path'Clean_Ozdenetal11.do"
		do "`path'Clean_main.do"
		do "`path'Count_grouped_data.do"
		do "`path'Histograms.do"
		do "`path'Descr_tables.do"
		do "`path'Graphs_shares.do"
		do "`path'Graphs_countrypairs.do"
		do "`path'Regressions.do"
		do "`path'Tables.do"
		do "`path'Do_tables.do"
	}

  **** Execute programs

	forvalues i=1/1 {
		cap log close Main_log
		local path="$logfold"
		log using "`path'/Main_log.smcl", replace name(Main_log)
		
		cleanozden "1"
		cleanmain "1" "4"
		countgroup "1"
		histograms "1"
		descriptives "1"
		immigrate "1"
		countrypairs "1"
		regs "1"
		
		log close Main_log
	}

 ***********************************************************************************
