
 *********** Regressions for determinants of bilateral migration stocks ************

  program define regs
 	local silent `1'
	****  CODEBOOK FOR SILENT:
	*   1 -> Nice stata output display
	*   0 -> Display everything 
	*************************************
	
 
  ******  Local variables to run the stuff quietly or noisily	
  
	if `silent'==1 {
		local sil "qui"
		local noi " "
	}
	else {
		local sil " "
		local noi "qui"
	}

  ******* Program starts
  
  
  	di " "
	di "   Does the regressions for the tables in the article", as text
	di "---------------------------------------------------------------------------"

	di "      Read data", as text _continue
	local path="$data"
	`sil' use "`path'Collapsed.dta", clear
	di "...", as text
	
	`sil' egen ortime=group(groupid period)
	
	* Table 5 - Determinants of Bilateral Migration Stocks - Linear Effects

	di "      Table 5", as text _continue
	
	matrix coefreglinear=J(11,7,.)
	matrix sesreglinear=J(9,7,.)
	
	local vlst5 "ydest yor ygap ldist comlang colony border lnpopor lnpopdest"

	local v51 "ydest yor ldist comlang colony border lnpopor lnpopde dt_* dj_* di_*"
	local v52 "ygap ldist comlang colony border lnpopor lnpopdest dt_* dj_* di_*"
	local v53 "ydest yor ldist comlang colony border lnpopor lnpopd dt_* dj_* di_*"
	local v53 "`v53' if wt==1"
	local v54 "ydest ldist comlang colony border lnpopdest djt_* di_*"
	local v55 "yor ldist comlang colony border lnpopor dj_* dit_*"
	local v56 "ydest yor lnpopor lnpopdest dt_* dij_*"
	local v57 "ydest yor ldist comlang colony border lnpopor lnpopde dt_* dj_* di_*"
	local v57 "`v57' st_lnstock st_ydest st_yor st_ldist st_comlang st_colony"
	local v57 "`v57' st_border st_lnpopor st_lnpopdest"
	
	
	forvalues i=1/7 {
		`sil' reg lnstock `v5`i'' [pweight=wt], cl(ortime) noc
	
		cap matrix coefreglinear[10,`i']=e(N)
		cap matrix coefreglinear[11,`i']=e(r2_a)

		local j=1
		foreach coeff of local vlst5 {
			cap matrix coefreglinear[`j',`i']=_b[`coeff']
			cap matrix sesreglinear[`j',`i']=_se[`coeff']
			cap if _b[`coeff']!=-999999 {
				local ++j
			}
		}
		
		if `i'==3 | `i'==7 {
			local j=1
			local test " "
			foreach coeff of local vlst5 {
				if "`coeff'"!="ygap" {
					local val=coefreglinear[`j',1]
					local test="`test' (_b[`coeff']=`val')"
				}
				local ++j
			}
			`sil' test `test')
			if `i'== 3 {
				matrix tests=r(p)
			}
			else {
				matrix tests=tests\(r(p))
			}
		}
	}
	
	di "...", as text

	
	* Table A1 - Linear Effects --- Introducing GDP per Capita in Logs
	
	di "      Table A1", as text _continue

	matrix coefreglinlog=J(11,7,.)
	matrix sesreglinlog=J(9,7,.)
	
	local vlstA1 "lnydest lnyor lnygap ldist comlang colony border lnpopor"
	local vlstA1 "`vlstA1' lnpopdest"

	local vA11 "lnydest lnyor ldist comlang colony border lnpopor lnpopde dt_* dj_*"
	local vA11 "`vA11' di_*"
	local vA12 "lnygap ldist comlang colony border lnpopor lnpopdest dt_* dj_* di_*"
	local vA13 "lnydest lnyor ldist comlang colony border lnpopor lnpopd dt_* dj_*"
	local vA13 "`vA13' di_* if wt==1"
	local vA14 "lnydest ldist comlang colony border lnpopdest djt_* di_*"
	local vA15 "lnyor ldist comlang colony border lnpopor dj_* dit_*"
	local vA16 "lnydest lnyor lnpopor lnpopdest dt_* dij_*"
	local vA17 "lnydest lnyor ldist comlang colony border lnpopor lnpopde dt_* dj_*"
	local vA17 "`vA17' di_* st_lnstock st_lnydest st_lnyor st_ldist st_comlang"
	local vA17 "`vA17' st_colony st_border st_lnpopor st_lnpopdest"
	
	
	forvalues i=1/7 {
		`sil' reg lnstock `vA1`i'' [pweight=wt], cl(ortime) noc
		
		cap matrix coefreglinlog[10,`i']=e(N)
		cap matrix coefreglinlog[11,`i']=e(r2_a)

		local j=1
		foreach coeff of local vlstA1 {
			cap matrix coefreglinlog[`j',`i']=_b[`coeff']
			cap matrix sesreglinlog[`j',`i']=_se[`coeff']
			cap if _b[`coeff']!=-999999 {
				local ++j
			}
		}
	}
	di "...", as text
	

	
	* Table A2 - Linear Effects --- \citet{Ozdenetal11} Data
	
	di "      Table A2", as text _continue
	
	matrix coefreglinozd=J(11,6,.)
	matrix sesreglinozd=J(9,6,.)
	
	local vlstA2 "ydest yor ygap ldist comlang colony border lnpopor lnpopdest"

	local vA21 "ydest yor ldist comlang colony border lnpopor lnpopde dt_* dj_*"
	local vA21 "`vA21' di_*"
	local vA22 "ygap ldist comlang colony border lnpopor lnpopdest dt_* dj_* di_*"
	local vA23 "ydest yor ldist comlang colony border lnpopor lnpopd dt_* dj_* di_*"
	local vA23 `"`vA23' if group=="NIU""'
	local vA24 "ydest ldist comlang colony border lnpopdest djt_* di_*"
	local vA25 "yor ldist comlang colony border lnpopor dj_* dit_*"
	local vA26 "ydest yor lnpopor lnpopdest dt_* dij_*"

	preserve
		local path="$data"
		`sil' use "`path'Bilateraldata.dta", clear
		
		`sil' egen ortime=group(codej period)
		
		`sil' gen lnstockozdenetal = ln(stockozdenetal)
		`sil' replace lnstockozdenetal = 0 if stockozdenetal==0
		
		forvalues i=1/6 {
			`sil' reg lnstockozdenetal `vA2`i'', cl(ortime) noc
			
			cap matrix coefreglinozd[10,`i']=e(N)
			cap matrix coefreglinozd[11,`i']=e(r2_a)

			local j=1
			foreach coeff of local vlstA2 {
				cap matrix coefreglinozd[`j',`i']=_b[`coeff']
				cap matrix sesreglinozd[`j',`i']=_se[`coeff']
				cap if _b[`coeff']!=-999999 {
					local ++j
				}
			}
		}
	restore		
	
	di "...", as text

	
	* Table 6 - Heterogeneous Effects of Income Gains
	
	di "      Table 6", as text _continue

	matrix coefreghet=J(18,6,.)
	matrix sesreghet=J(16,6,.)
	
	local vlst6 "ydest ydest_ldist ydest_comlang ydest_colony ydest_border yor" 
	local vlst6 "`vlst6' yor_ldist yor_comlang yor_colony yor_border ldist" 
	local vlst6 "`vlst6' comlang colony border lnpopor lnpopdest "

	local v61 "ydest ydest_ldist yor yor_ldist ldist comlang colony border lnpopor" 
	local v61 "`v61' lnpopdest dt_* dj_* di_*"
	
	local v62 "ydest ydest_ldist ydest_comlang ydest_colony ydest_border yor"
	local v62 "`v62' yor_ldist yor_comlang yor_colony yor_border ldist comlang"
	local v62 "`v62' colony border lnpopor lnpopdest dt_* dj_* di_*"
	
	local v63 "ydest ydest_ldist ydest_comlang ydest_colony ydest_border yor"
	local v63 "`v63' yor_ldist yor_comlang yor_colony yor_border ldist comlang"
	local v63 "`v63' colony border lnpopor lnpopdest dt_* dj_* di_* if wt==1"
	
	local v64 "ydest ydest_ldist ydest_comlang ydest_colony ydest_border"
	local v64 "`v64' yor_ldist yor_comlang yor_colony yor_border ldist comlang"
	local v64 "`v64' colony border lnpopdest djt_* di_*"
		
	local v65 "ydest_ldist ydest_comlang ydest_colony ydest_border yor yor_ldist"
	local v65 "`v65' yor_comlang yor_colony yor_border ldist comlang colony border"
	local v65 "`v65' lnpopor dj_* dit_*"
	
	local v66 "ydest ydest_ldist ydest_comlang ydest_colony ydest_border yor"
	local v66 "`v66' yor_ldist yor_comlang yor_colony yor_border lnpopor lnpopdest"
	local v66 "`v66' dt_* dij_*" 
	
	
	forvalues i=1/6 {
		`sil' reg lnstock `v6`i'' [pweight=wt], cl(ortime) noc

		capture matrix coefreghet[17,`i']=e(N)
		capture matrix coefreghet[18,`i']=e(r2_a)
		
		local j=1
		foreach coeff of local vlst6 {
			cap matrix coefreghet[`j',`i']=_b[`coeff']
			cap matrix sesreghet[`j',`i']=_se[`coeff']
			cap if _b[`coeff']!=-999999 {
				local ++j
			}
		}
		
		if `i'==1 {
			`sil' test (_b[ydest_ldist]+_b[yor_ldist]=0)
			matrix testshet=r(p)
		}
		if `i'==3 {
			local j=1
			local test " "
			local test2 " "
			local test3 " "
			foreach coeff of local vlst6 {
				local val=coefreghet[`j',2]
				if `j'<8 {
					local test="`test' (_b[`coeff']=`val')"
				}
				else if `j'<15 {
					local test2="`test2' (_b[`coeff']=`val')"
				}
				else {
					local test3="`test3' (_b[`coeff']=`val')"
				}
				local ++j
			}
			`sil' test `test' `test2' `test3'
			matrix testshet=testshet\(r(p))
		}
	}
	di "...", as text
	
	
	* Table B1 - Heterogeneous Effects of Income Gains --- GDP per Capita in Logs
	
	di "      Table B1", as text _continue

	matrix coefreghetlog=J(18,6,.)
	matrix sesreghetlog=J(16,6,.)
	
	local vlstB1 "lnydest lnydest_ldist lnydest_comlang lnydest_colony" 
	local vlstB1 "`vlstB1' lnydest_border lnyor lnyor_ldist lnyor_comlang" 
	local vlstB1 "`vlstB1' lnyor_colony lnyor_border ldist comlang colony border" 
	local vlstB1 "`vlstB1' lnpopor lnpopdest"

	local vB11 "lnydest lnydest_ldist lnyor lnyor_ldist ldist comlang colony border" 
	local vB11 "`vB11' lnpopor lnpopdest dt_* dj_* di_*"
	
	local vB12 "lnydest lnydest_ldist lnydest_comlang lnydest_colony lnydest_border" 
	local vB12 "`vB12' lnyor lnyor_ldist lnyor_comlang lnyor_colony lnyor_border"
	local vB12 "`vB12' ldist comlang colony border lnpopor lnpopdest dt_* dj_* di_*"
	
	local vB13 "lnydest lnydest_ldist lnydest_comlang lnydest_colony lnydest_border"
	local vB13 "`vB13' lnyor lnyor_ldist lnyor_comlang lnyor_colony lnyor_border"
	local vB13 "`vB13' ldist comlang colony border lnpopor lnpopdest dt_* dj_* di_*"
	local vB13 "`vB13' if wt==1"
	
	local vB14 "lnydest lnydest_ldist lnydest_comlang lnydest_colony lnydest_border"
	local vB14 "`vB14' lnyor_ldist lnyor_comlang lnyor_colony lnyor_border ldist"
	local vB14 "`vB14' comlang colony border lnpopdest djt_* di_*"
		
	local vB15 "lnydest_ldist lnydest_comlang lnydest_colony lnydest_border lnyor"
	local vB15 "`vB15' lnyor_ldist lnyor_comlang lnyor_colony lnyor_border ldist"
	local vB15 "`vB15' comlang colony border lnpopor dj_* dit_*"
	
	local vB16 "lnydest lnydest_ldist lnydest_comlang lnydest_colony lnydest_border"
	local vB16 "`vB16' lnyor lnyor_ldist lnyor_comlang lnyor_colony lnyor_border"
	local vB16 "`vB16' lnpopor lnpopdest dt_* dij_*" 
	
	
	forvalues i=1/6 {
		`sil' reg lnstock `vB1`i'' [pweight=wt], cl(ortime) noc
		
		capture matrix coefreghetlog[17,`i']=e(N)
		capture matrix coefreghetlog[18,`i']=e(r2_a)

		local j=1
		foreach coeff of local vlstB1 {
			cap matrix coefreghetlog[`j',`i']=_b[`coeff']
			cap matrix sesreghetlog[`j',`i']=_se[`coeff']
			cap if _b[`coeff']!=-999999 {
				local ++j
			}
		}
	}
	di "...", as text
	

	
	* Table B2 - Heterogeneous Effects of Income Gains --- \citet{Ozdenetal11} Data
	
	di "      Table B2", as text _continue
	
	matrix coefreghetozd=J(18,6,.)
	matrix sesreghetozd=J(16,6,.)
	
	local vlstB2 "ydest ydest_ldist ydest_comlang ydest_colony ydest_border yor" 
	local vlstB2 "`vlstB2' yor_ldist yor_comlang yor_colony yor_border ldist" 
	local vlstB2 "`vlstB2' comlang colony border lnpopor lnpopdest "

	local vB21 "ydest ydest_ldist yor yor_ldist ldist comlang colony border lnpopor" 
	local vB21 "`vB21' lnpopdest dt_* dj_* di_*"
	
	local vB22 "ydest ydest_ldist ydest_comlang ydest_colony ydest_border yor"
	local vB22 "`vB22' yor_ldist yor_comlang yor_colony yor_border ldist comlang"
	local vB22 "`vB22' colony border lnpopor lnpopdest dt_* dj_* di_*"
	
	local vB23 "ydest ydest_ldist ydest_comlang ydest_colony ydest_border yor"
	local vB23 "`vB23' yor_ldist yor_comlang yor_colony yor_border ldist comlang"
	local vB23 "`vB23' colony border lnpopor lnpopdest dt_* dj_* di_*"
	local vB23 `"`vB23' if group=="NIU""'
	
	local vB24 "ydest ydest_ldist ydest_comlang ydest_colony ydest_border"
	local vB24 "`vB24' yor_ldist yor_comlang yor_colony yor_border ldist comlang"
	local vB24 "`vB24' colony border lnpopdest djt_* di_*"
		
	local vB25 "ydest_ldist ydest_comlang ydest_colony ydest_border yor yor_ldist"
	local vB25 "`vB25' yor_comlang yor_colony yor_border ldist comlang colony border"
	local vB25 "`vB25' lnpopor dj_* dit_*"
	
	local vB26 "ydest ydest_ldist ydest_comlang ydest_colony ydest_border yor"
	local vB26 "`vB26' yor_ldist yor_comlang yor_colony yor_border lnpopor"
	local vB26 "`vB26' lnpopdest dt_* dij_*" 
	

	preserve
		local path="$data"
		`sil' use "`path'Bilateraldata.dta", clear
		
		`sil' egen ortime=group(codej period)
		
		`sil' gen lnstockozdenetal = ln(stockozdenetal)
		`sil' replace lnstockozdenetal = 0 if stockozdenetal==0
		
		forvalues i=1/6 {
			`sil' reg lnstockozdenetal `vB2`i'', cl(ortime) noc
			
			cap matrix coefreghetozd[17,`i']=e(N)
			cap matrix coefreghetozd[18,`i']=e(r2_a)

			local j=1
			foreach coeff of local vlstB2 {
				cap matrix coefreghetozd[`j',`i']=_b[`coeff']
				cap matrix sesreghetozd[`j',`i']=_se[`coeff']
				cap if _b[`coeff']!=-999999 {
					local ++j
				}
			}
		}
	restore		
	
	di "...", as text
	
	* Table 7 - Additional Results
		
	matrix coefregadd=J(20,9,.)
	matrix sesregadd=J(18,9,.)
	
	local vlst7 "ydest ydest_ldist udest agedepdest govdest yor yor_ldist waror"
	local vlst7 "`vlst7' polity pol2 lnyoung ldist comlang colony border networks"
	local vlst7 "`vlst7' lnpopor lnpopdest"

	local v71 "lnstock ydest ydest_ldist udest yor yor_ldist ldist comlang colony"
	local v71 "`v71' border lnpopor lnpopdest dt_* dj_* di_*"
	
	local v72 "lnstock ydest ydest_ldist agedepdest yor yor_ldist ldist comlang"
	local v72 "`v72' colony border lnpopor lnpopdest dt_* dj_* di_*"
	
	local v73 "lnstock ydest ydest_ldist govdest yor yor_ldist ldist comlang colony"
	local v73 "`v73' border lnpopor lnpopdest dt_* dj_* di_*"
	
	local v74 "lnstock ydest ydest_ldist yor yor_ldist waror ldist comlang colony"
	local v74 "`v74' border lnpopor lnpopdest dt_* dj_* di_*"
	
	local v75 "lnstock ydest ydest_ldist yor yor_ldist polity pol2 ldist comlang"
	local v75 "`v75' colony border lnpopor lnpopdest dt_* dj_* di_*"
	
	local v76 "lnstock ydest ydest_ldist yor yor_ldist lnyoung ldist comlang colony"
	local v76 "`v76' border lnpopor lnpopdest dt_* dj_* di_*"
	
	local v77 "lnstock ydest ydest_ldist udest agedepdest govdest yor yor_ldist"
	local v77 "`v77' waror polity pol2 lnyoung ldist comlang colony border lnpopor"
	local v77 "`v77' lnpopdest dt_* dj_* di_*"
	
	local v78 "lnstock ydest ydest_ldist yor yor_ldist ldist comlang colony border"
	local v78 "`v78' networks lnpopor lnpopdest dt_* dj_* di_*"
	
	local v79 "lnflow ydest ydest_ldist yor yor_ldist ldist comlang colony border"
	local v79 "`v79' lnpopor lnpopdest dt_* dj_* di_*"
	
	
	forvalues i=1/9 {
		if `i'==8 {
			preserve
			
			local path="$data"
			`sil' use "`path'Collapsed_networks.dta", clear
			
			`sil' egen ortime=group(biggroup period)
			`sil' egen codeij=group(biggroup codei)
			`sil' drop if codeij==.
			`sil' xtset codeij period
			`sil' gen lnflow=ln(exp(lnstock)-exp(ll.lnstock))
			
		}
			`sil' reg `v7`i'' [pweight=wt], cl(ortime) noc
			
			capture matrix coefregadd[19,`i']=e(N)
			capture matrix coefregadd[20,`i']=e(r2_a)

			local j=1
			foreach coeff of local vlst7 {
				capture matrix coefregadd[`j',`i']=_b[`coeff']
				capture matrix sesregadd[`j',`i']=_se[`coeff']
				local ++j
			}
		if `i'==9 {
			restore
		}
	}
	
	* Do the tables
	
	tables "1"
	
end
	


	
	* Table A2 - Linear Effects --- Networks
	
	di "      Table A2", as text _continue
	
	matrix coefreglinnet=J(13,7,.)
	matrix sesreglinnet=J(11,7,.)
		
	local vlstA2 "networks ydest yor lnydest lnyor ldist comlang colony border"
	local vlstA2 "`vlstA2' lnpopor lnpopdest"

	local vA21 "ydest yor ldist comlang colony border lnpopor lnpopde dt_* dj_*"
	local vA21 "`vA21'  di_* if networks!=."
	local vA22 "networks ydest yor ldist comlang colony border lnpopor lnpopdest"
	local vA22 "`vA22' dt_* dj_* di_*"
	local vA23 "networks lnydest lnyor ldist comlang colony border lnpopor"
	local vA23 "`vA23' lnpopdest dt_* dj_* di_*"
	local vA24 "networks ydest yor ldist comlang colony border lnpopor lnpopd"
	local vA24 "`vA24' dt_* dj_* di_* if wt==1"
	local vA25 "networks ydest ldist comlang colony border lnpopdest djt_* di_*"
	local vA26 "networks yor ldist comlang colony border lnpopor dj_*"
	local vA26 "`vA26' dit_*"
	local vA27 "networks ydest yor lnpopor lnpopdest dt_* dij_*"		

	preserve
		local path="$data"
		`sil' use "`path'Collapsed_networks.dta", clear
		
		`sil' egen ortime=group(biggroup period)

		
		forvalues i=1/7 {
			`sil' reg lnstock `vA2`i'' [pweight=wt], cl(ortime) noc
			
			cap matrix coefreglinnet[12,`i']=e(N)
			cap matrix coefreglinnet[13,`i']=e(r2_a)

			local j=1
			foreach coeff of local vlstA2 {
				cap matrix coefreglinnet[`j',`i']=_b[`coeff']
				cap matrix sesreglinnet[`j',`i']=_se[`coeff']
				cap if _b[`coeff']!=-999999 {
					local ++j
				}
			}
		}
	restore		
	
	di "...", as text
	
	* Table B2 - Heterogeneous Effects of Income Gains --- Networks
	
	di "      Table B2", as text _continue

	matrix coefreghetnet=J(19,6,.)
	matrix sesreghetnet=J(17,6,.)
	
	local vlstB2 "networks ydest ydest_ldist ydest_comlang ydest_colony" 
	local vlstB2 "`vlstB2' ydest_border yor yor_ldist yor_comlang" 
	local vlstB2 "`vlstB2' yor_colony yor_border ldist comlang colony border" 
	local vlstB2 "`vlstB2' lnpopor lnpopdest"

	local vB21 "networks ydest ydest_ldist yor yor_ldist ldist comlang colony" 
	local vB21 "`vB21' border lnpopor lnpopdest dt_* dj_* di_*"
	
	local vB22 "networks ydest ydest_ldist ydest_comlang ydest_colony ydest_border" 
	local vB22 "`vB22' yor yor_ldist yor_comlang yor_colony yor_border"
	local vB22 "`vB22' ldist comlang colony border lnpopor lnpopdest dt_* dj_* di_*"
	
	local vB23 "networks ydest ydest_ldist ydest_comlang ydest_colony ydest_border"
	local vB23 "`vB23' yor yor_ldist yor_comlang yor_colony yor_border"
	local vB23 "`vB23' ldist comlang colony border lnpopor lnpopdest dt_* dj_* di_*"
	local vB23 "`vB23' if wt==1"
	
	local vB24 "networks ydest ydest_ldist ydest_comlang ydest_colony ydest_border"
	local vB24 "`vB24' yor_ldist yor_comlang yor_colony yor_border ldist"
	local vB24 "`vB24' comlang colony border lnpopdest djt_* di_*"
		
	local vB25 "networks ydest_ldist ydest_comlang ydest_colony ydest_border yor"
	local vB25 "`vB25' yor_ldist yor_comlang yor_colony yor_border ldist"
	local vB25 "`vB25' comlang colony border lnpopor dj_* dit_*"
	
	local vB26 "networks ydest ydest_ldist ydest_comlang ydest_colony ydest_border"
	local vB26 "`vB26' yor yor_ldist yor_comlang yor_colony yor_border"
	local vB26 "`vB26' lnpopor lnpopdest dt_* dij_*" 
	
	preserve
		local path="$data"
		`sil' use "`path'Collapsed_networks.dta", clear
		
		`sil' egen ortime=group(biggroup period)
		
		forvalues i=1/6 {
			`sil' reg lnstock `vB2`i'' [pweight=wt], cl(ortime) noc

			capture matrix coefreghetnet[18,`i']=e(N)
			capture matrix coefreghetnet[19,`i']=e(r2_a)

			local j=1
			foreach coeff of local vlstB2 {
				cap matrix coefreghetnet[`j',`i']=_b[`coeff']
				cap matrix sesreghetnet[`j',`i']=_se[`coeff']
				cap if _b[`coeff']!=-999999 {
					local ++j
				}
			}
		}
	restore
	
	di "...", as text

	
